@@ -11,9 +11,9 @@
 #'          in the \code{hexcols} slot of the Radviz object, cells will be colored
 #'          using colors in the \code{hexcols} slot
 #' @param label.color the color of springs for visualization
-#' @param label.size the size of labels
-#' @param mincnt deprecated, see \code{\link{stat_summary_hex}} instead
-#' @param style deprecated, see \code{\link{stat_summary_hex}} instead
+#' @param label.size the size of the anchors (see \href{https://ggplot2.tidyverse.org/articles/articles/faq-customising.html}{customizing ggplot2} for details on default value)
+#' @param mincnt deprecated, see \code{\link[ggplot2]{stat_summary_hex}} instead
+#' @param style deprecated, see \code{\link[ggplot2]{stat_summary_hex}} instead
 #' 
 #' @return the internal ggplot2 object plus added layers, allowing for extra geoms to be added
 #' 
@@ -21,7 +21,7 @@
 #' @examples
 #' hexplot(rv,color='Sepal.Length')
 #' 
-#' @importFrom ggplot2 ggtitle aes_string scale_fill_gradient geom_hex stat_summary_hex
+#' @importFrom ggplot2 aes_string scale_fill_gradient geom_hex stat_summary_hex 
 #' @import hexbin
 #' 
 #' @author Yann Abraham
@@ -42,20 +42,13 @@ hexplot <- function(x,
     warning('style is a deprecated argument, use plot(x)+stat_summary_hex() and custom aes() to change plot.',call. = FALSE)
   
   ## plot
-  p <- x$proj+
-    ggtitle(main)+
+  p <- plot.radviz(x,
+                   main = main,
+                   label.color = label.color,
+                   label.size = label.size)
+  p <- p+
     scale_fill_gradient(low='grey90',high='dodgerblue4')
   
-  if(!is.null(label.color) | !is.null(label.size)) {
-    if(is.null(label.size)) label.size <- NA
-    if(is.null(label.color)) label.color <- 'orangered4'
-    if(!is.numeric(label.size)) label.size <- as.numeric(label.size)
-    p$layers[[1]] <- geom_text(data = p$layers[[1]]$data,
-                               aes_string(x='X1',y='X2',label='Channel'),
-                               color=label.color,
-                               size=label.size)
-  }
-  
   if(is.null(color)) {
     slayer <- geom_hex(bins=nbins)
   } else {
